@@ -1,21 +1,21 @@
 ### S3 tool function for writing.
 
 comm.read.table <- function(file, header = FALSE, sep = "", quote = "\"'",
-    dec = ".", col.names, 
+    dec = ".",
     na.strings = "NA", colClasses = NA, nrows = -1, skip = 0,
     check.names = TRUE, fill = !blank.lines.skip, strip.white = FALSE,
     blank.lines.skip = TRUE, comment.char = "#", allowEscapes = FALSE,
     flush = FALSE,
-    fileEncoding = "", encoding = "unknown", text,
-    read.method = .SPMD.IO$read.method[1],
-    balance.method = .SPMD.IO$balance.method[1],
-    comm = .SPMD.CT$comm){
+    fileEncoding = "", encoding = "unknown",
+    read.method = .pbd_env$SPMD.IO$read.method[1],
+    balance.method = .pbd_env$SPMD.IO$balance.method[1],
+    comm = .pbd_env$SPMD.CT$comm){
   ### Read by method.
   ret <- NULL
   if(read.method[1] == "gbd"){
     ret <- read.table.gbd(
              file, header = header, sep = sep, quote = quote,
-             dec = dec, col.names,
+             dec = dec,
              na.strings = na.strings, colClasses = colClasses,
              nrows = nrows, skip = skip,
              check.names = check.names, fill = fill,
@@ -23,13 +23,13 @@ comm.read.table <- function(file, header = FALSE, sep = "", quote = "\"'",
              blank.lines.skip = blank.lines.skip,
              comment.char = comment.char,
              allowEscapes = allowEscapes, flush = flush,
-             fileEncoding = fileEncoding, encoding = encoding, text,
+             fileEncoding = fileEncoding, encoding = encoding,
              balance.method = balance.method,
              comm = comm)
   } else if(read.method[1] == "common"){
     ret <- read.table.common(
              file, header = header, sep = sep, quote = quote,
-             dec = dec, col.names,
+             dec = dec,
              na.strings = na.strings, colClasses = colClasses,
              nrows = nrows, skip = skip,
              check.names = check.names, fill = fill,
@@ -37,7 +37,7 @@ comm.read.table <- function(file, header = FALSE, sep = "", quote = "\"'",
              blank.lines.skip = blank.lines.skip,
              comment.char = comment.char,
              allowEscapes = allowEscapes, flush = flush,
-             fileEncoding = fileEncoding, encoding = encoding, text,
+             fileEncoding = fileEncoding, encoding = encoding,
              comm = comm)
   } else{
     comm.stop("read.method is undefined.", comm = comm)
@@ -49,14 +49,14 @@ comm.read.table <- function(file, header = FALSE, sep = "", quote = "\"'",
 
 
 read.table.gbd <- function(file, header = FALSE, sep = "",
-    quote = "\"'", dec = ".", col.names,
+    quote = "\"'", dec = ".",
     na.strings = "NA", colClasses = NA, nrows = -1, skip = 0,
     check.names = TRUE, fill = !blank.lines.skip, strip.white = FALSE,
     blank.lines.skip = TRUE, comment.char = "#", allowEscapes = FALSE,
     flush = FALSE,
-    fileEncoding = "", encoding = "unknown", text,
-    balance.method = .SPMD.IO$balance.method[1],
-    comm = .SPMD.CT$comm){
+    fileEncoding = "", encoding = "unknown",
+    balance.method = .pbd_env$SPMD.IO$balance.method[1],
+    comm = .pbd_env$SPMD.CT$comm){
   COMM.SIZE <- spmd.comm.size(comm = comm)
   COMM.RANK <- spmd.comm.rank(comm = comm)
 
@@ -73,17 +73,17 @@ read.table.gbd <- function(file, header = FALSE, sep = "",
     file.size <- as.double(file.info(file)$size)
   }
   file.size <- spmd.bcast.double(file.size, comm = comm)
-  if(file.size > .SPMD.IO$max.read.size){
-    comm.cat("Caution: file size exceeds .SPMD.IO$max.read.size.\n",
+  if(file.size > .pbd_env$SPMD.IO$max.read.size){
+    comm.cat("Caution: file size exceeds .pbd_env$SPMD.IO$max.read.size.\n",
              comm = comm, quiet = TRUE)
   }
 
   ### Read start.
   if(comm.all(nrows == -1) && comm.all(skip == 0)){
-    if(file.size < .SPMD.IO$max.read.size){
+    if(file.size < .pbd_env$SPMD.IO$max.read.size){
       if(COMM.RANK == 0){
         tmp <- read.table(file, header = header, sep = sep, quote = quote,
-                          dec = dec, col.names, as.is = TRUE,
+                          dec = dec, as.is = TRUE,
                           na.strings = na.strings, colClasses = colClasses,
                           nrows = nrows, skip = skip,
                           check.names = check.names, fill = fill,
@@ -92,8 +92,7 @@ read.table.gbd <- function(file, header = FALSE, sep = "",
                           comment.char = comment.char,
                           allowEscapes = allowEscapes, flush = flush,
                           stringsAsFactors = FALSE,
-                          fileEncoding = fileEncoding, encoding = encoding,
-                          text)
+                          fileEncoding = fileEncoding, encoding = encoding)
 
         ### Get divided indices.
         alljid <- get.jid(nrow(tmp), all = TRUE)
@@ -113,7 +112,8 @@ read.table.gbd <- function(file, header = FALSE, sep = "",
       ### Predict total lines.
       tl.pred <- 0L
       if(COMM.RANK == 0){
-        tmp <- nchar(readLines(con = file, n = .SPMD.IO$max.test.lines))
+        tmp <- nchar(readLines(con = file,
+                               n = .pbd_env$SPMD.IO$max.test.lines))
         tl.pred <- ceiling(file.size / sum(tmp) * length(tmp))
       }
       tl.pred <- spmd.bcast.integer(as.integer(tl.pred), comm = comm)
@@ -131,7 +131,7 @@ read.table.gbd <- function(file, header = FALSE, sep = "",
       for(i.rank in 0:(COMM.SIZE - 1)){
         if(COMM.RANK == i.rank){
           ret <- read.table(file, header = header, sep = sep, quote = quote,
-                            dec = dec, col.names, as.is = TRUE,
+                            dec = dec, as.is = TRUE,
                             na.strings = na.strings, colClasses = colClasses,
                             nrows = nrows, skip = skip,
                             check.names = check.names, fill = fill,
@@ -140,8 +140,7 @@ read.table.gbd <- function(file, header = FALSE, sep = "",
                             comment.char = comment.char,
                             allowEscapes = allowEscapes, flush = flush,
                             stringsAsFactors = FALSE,
-                            fileEncoding = fileEncoding, encoding = encoding,
-                            text)
+                            fileEncoding = fileEncoding, encoding = encoding)
         }
         spmd.barrier(comm = comm)
       }
@@ -158,7 +157,7 @@ read.table.gbd <- function(file, header = FALSE, sep = "",
     for(i.rank in 0:(COMM.SIZE - 1)){
       if(i.rank == COMM.RANK){
         ret <- read.table(file, header = header, sep = sep, quote = quote,
-                          dec = dec, col.names, as.is = TRUE,
+                          dec = dec, as.is = TRUE,
                           na.strings = na.strings, colClasses = colClasses,
                           nrows = nrows, skip = skip,
                           check.names = check.names, fill = fill,
@@ -167,8 +166,7 @@ read.table.gbd <- function(file, header = FALSE, sep = "",
                           comment.char = comment.char,
                           allowEscapes = allowEscapes, flush = flush,
                           stringsAsFactors = FALSE,
-                          fileEncoding = fileEncoding, encoding = encoding,
-                          text)
+                          fileEncoding = fileEncoding, encoding = encoding)
       }
       spmd.barrier(comm = comm)
     }
@@ -181,13 +179,13 @@ read.table.gbd <- function(file, header = FALSE, sep = "",
 
 
 read.table.common <- function(file, header = FALSE, sep = "",
-    quote = "\"'", dec = ".", col.names,
+    quote = "\"'", dec = ".",
     na.strings = "NA", colClasses = NA, nrows = -1, skip = 0,
     check.names = TRUE, fill = !blank.lines.skip, strip.white = FALSE,
     blank.lines.skip = TRUE, comment.char = "#", allowEscapes = FALSE,
     flush = FALSE,
-    fileEncoding = "", encoding = "unknown", text,
-    comm = .SPMD.CT$comm){
+    fileEncoding = "", encoding = "unknown",
+    comm = .pbd_env$SPMD.CT$comm){
   COMM.SIZE <- spmd.comm.size(comm = comm)
   COMM.RANK <- spmd.comm.rank(comm = comm)
 
@@ -204,8 +202,8 @@ read.table.common <- function(file, header = FALSE, sep = "",
     file.size <- as.double(file.info(file)$size)
   }
   file.size <- spmd.bcast.double(file.size, comm = comm)
-  if(file.size > .SPMD.IO$max.read.size){
-    comm.cat("Caution: file size exceeds .SPMD.IO$max.read.size.\n",
+  if(file.size > .pbd_env$SPMD.IO$max.read.size){
+    comm.cat("Caution: file size exceeds .pbd_env$SPMD.IO$max.read.size.\n",
              comm = comm, quiet = TRUE)
   }
 
@@ -224,11 +222,11 @@ read.table.common <- function(file, header = FALSE, sep = "",
   }
 
   ### Read start.
-  if(file.size < .SPMD.IO$max.read.size){
+  if(file.size < .pbd_env$SPMD.IO$max.read.size){
     ### Ths file is small, so we read from rank 0 and bcast to all.
     if(COMM.RANK == 0){
       ret <- read.table(file, header = header, sep = sep, quote = quote,
-                        dec = dec, col.names, as.is = TRUE,
+                        dec = dec, as.is = TRUE,
                         na.strings = na.strings, colClasses = colClasses,
                         nrows = nrows, skip = skip,
                         check.names = check.names, fill = fill,
@@ -237,8 +235,7 @@ read.table.common <- function(file, header = FALSE, sep = "",
                         comment.char = comment.char,
                         allowEscapes = allowEscapes, flush = flush,
                         stringsAsFactors = FALSE,
-                        fileEncoding = fileEncoding, encoding = encoding,
-                        text)
+                        fileEncoding = fileEncoding, encoding = encoding)
     }
     ret <- spmd.bcast.object(ret, comm = comm)
   } else{
@@ -247,7 +244,7 @@ read.table.common <- function(file, header = FALSE, sep = "",
     for(i.rank in 0:(COMM.SIZE - 1)){
       if(i.rank == COMM.RANK){
         ret <- read.table(file, header = header, sep = sep, quote = quote,
-                          dec = dec, col.names, as.is = TRUE,
+                          dec = dec, as.is = TRUE,
                           na.strings = na.strings, colClasses = colClasses,
                           nrows = nrows, skip = skip,
                           check.names = check.names, fill = fill,
@@ -256,8 +253,7 @@ read.table.common <- function(file, header = FALSE, sep = "",
                           comment.char = comment.char,
                           allowEscapes = allowEscapes, flush = flush,
                           stringsAsFactors = FALSE,
-                          fileEncoding = fileEncoding, encoding = encoding,
-                          text)
+                          fileEncoding = fileEncoding, encoding = encoding)
       }
       spmd.barrier(comm = comm)
     }
@@ -270,9 +266,9 @@ read.table.common <- function(file, header = FALSE, sep = "",
 
 comm.read.csv <- function(file, header = TRUE, sep = ",", quote = "\"",
     dec = ".", fill = TRUE, comment.char = "", ..., 
-    read.method = .SPMD.IO$read.method[1],
-    balance.method = .SPMD.IO$balance.method[1],
-    comm = .SPMD.CT$comm){
+    read.method = .pbd_env$SPMD.IO$read.method[1],
+    balance.method = .pbd_env$SPMD.IO$balance.method[1],
+    comm = .pbd_env$SPMD.CT$comm){
   comm.read.table(file = file, header = header, sep = sep, quote = quote, 
                   dec = dec, fill = fill, comment.char = comment.char, ...,
                   read.method = read.method, balance.method = balance.method,
@@ -282,9 +278,9 @@ comm.read.csv <- function(file, header = TRUE, sep = ",", quote = "\"",
 
 comm.read.csv2 <- function(file, header = TRUE, sep = ";", quote = "\"",
     dec = ",", fill = TRUE, comment.char = "", ...,
-    read.method = .SPMD.IO$read.method[1],
-    balance.method = .SPMD.IO$balance.method[1],
-    comm = .SPMD.CT$comm){
+    read.method = .pbd_env$SPMD.IO$read.method[1],
+    balance.method = .pbd_env$SPMD.IO$balance.method[1],
+    comm = .pbd_env$SPMD.CT$comm){
   comm.read.table(file = file, header = header, sep = sep, quote = quote, 
                 dec = dec, fill = fill, comment.char = comment.char, ...,
                 read.method = read.method, balance.method = balance.method,
