@@ -1,6 +1,6 @@
 ### S3 tool function.
 
-comm.timer <- function(timed, comm = .SPMD.CT$comm){
+comm.timer <- function(timed, comm = .pbd_env$SPMD.CT$comm){
   ltime <- system.time(timed)[3]
 
   mintime <- allreduce(ltime, op = 'min', comm = comm)
@@ -13,8 +13,10 @@ comm.timer <- function(timed, comm = .SPMD.CT$comm){
 
 comm.Rprof <- function(filename = "Rprof.out", append = FALSE, interval = 0.02,
     memory.profiling = FALSE, gc.profiling = FALSE, line.profiling = FALSE,
-    numfiles = 100L, bufsize = 10000L, all.rank = .SPMD.CT$Rprof.all.rank,
-    rank.Rprof = .SPMD.CT$rank.source, comm = .SPMD.CT$comm){
+    numfiles = 100L, bufsize = 10000L,
+    all.rank = .pbd_env$SPMD.CT$Rprof.all.rank,
+    rank.Rprof = .pbd_env$SPMD.CT$rank.source,
+    comm = .pbd_env$SPMD.CT$comm){
   COMM.RANK <- spmd.comm.rank(comm)
   COMM.SIZE <- spmd.comm.size(comm)
 
