@@ -2,7 +2,8 @@
 
 ### Default method.
 spmd.bcast.default <- function(x,
-    rank.source = .SPMD.CT$rank.source, comm = .SPMD.CT$comm){
+    rank.source = .pbd_env$SPMD.CT$rank.source,
+    comm = .pbd_env$SPMD.CT$comm){
   if(spmd.comm.rank(comm) == rank.source){
     is.check <- spmd.bcast.integer(as.integer(is.array(x)), comm = comm)
   } else{
@@ -20,23 +21,33 @@ spmd.bcast.default <- function(x,
 
 ### For bcast and basic types.
 spmd.bcast.integer <- function(x,
-    rank.source = .SPMD.CT$rank.source, comm = .SPMD.CT$comm){
+    rank.source = .pbd_env$SPMD.CT$rank.source,
+    comm = .pbd_env$SPMD.CT$comm){
   .Call("spmd_bcast_integer", x,
         as.integer(rank.source), as.integer(comm), PACKAGE = "pbdMPI")
 } # End of spmd.bcast.integer().
 
 spmd.bcast.double <- function(x,
-    rank.source = .SPMD.CT$rank.source, comm = .SPMD.CT$comm){
+    rank.source = .pbd_env$SPMD.CT$rank.source,
+    comm = .pbd_env$SPMD.CT$comm){
   .Call("spmd_bcast_double", x,
         as.integer(rank.source), as.integer(comm), PACKAGE = "pbdMPI")
 } # End of spmd.bcast.double().
 
 spmd.bcast.raw <- function(x,
-    rank.source = .SPMD.CT$rank.source, comm = .SPMD.CT$comm){
+    rank.source = .pbd_env$SPMD.CT$rank.source,
+    comm = .pbd_env$SPMD.CT$comm){
   .Call("spmd_bcast_raw", x,
         as.integer(rank.source), as.integer(comm), PACKAGE = "pbdMPI")
 } # End of spmd.bcast.raw().
 
+spmd.bcast.string <- function(x,
+    rank.source = .pbd_env$SPMD.CT$rank.source,
+    comm = .pbd_env$SPMD.CT$comm){
+  .Call("spmd_bcast_string", x[1],
+        as.integer(rank.source), as.integer(comm), PACKAGE = "pbdMPI")
+} # End of spmd.bcast.string().
+
 
 ### S4 methods.
 setGeneric(
