@@ -24,8 +24,9 @@
   .Call("spmd_initialize", PACKAGE = "pbdMPI")
 
   ### For seed.
-  if(! exists(".lec.Random.seed.table", envir = .GlobalEnv) &&
-     ! exists(".Random.seed", envir = .GlobalEnv)){
+  # if(! exists(".lec.Random.seed.table", envir = .GlobalEnv) &&
+  #    ! exists(".Random.seed", envir = .GlobalEnv)){
+  if(! exists(".Random.seed", envir = .GlobalEnv)){
     # seed <- as.integer(Sys.getpid() + Sys.time())
     seed <- as.integer(runif(6, 1L, 2147483647L))
     seed <- .Call("spmd_bcast_integer", seed, 0L, 0L, PACKAGE = "pbdMPI")
@@ -36,11 +37,15 @@
     names <- as.character(0:(comm.size - 1))
     name <- as.character(comm.rank)
 
+    invisible(eval(.lec.old.kind <- RNGkind(), envir = .GlobalEnv))
     invisible(eval(.lec.SetPackageSeed(seed), envir = .GlobalEnv))
     invisible(eval(.lec.CreateStream(names), envir = .GlobalEnv))
     invisible(eval(.lec.CurrentStream(name), envir = .GlobalEnv))
   }
 
+  ### Preload to global environment.
+  invisible(eval(parse(text = "pbdMPI:::.mpiopt_init()")))
+
   invisible()
 } # End of .onLoad().
 
